CustomInkWell class

A custom InkWell widget that provides enhanced tap, double-tap, and secondary-tap functionalities without delaying single taps when double-tap is enabled.

Inheritance

Constructors

CustomInkWell({Key? key, required Widget child, VoidCallback? onTap, VoidCallback? onDoubleTap, void onSecondaryTapDown(TapDownDetails details, RenderBox renderBox)?, Duration doubleClickTime = const Duration(milliseconds: 500), required Color backgroundColor, Color? splashColor, Color? highlightColor, Color? hoverColor, BorderRadius? borderRadius})
Creates a CustomInkWell instance.
const

Properties

backgroundColor Color
final
borderRadius BorderRadius?
The border radius of the ink splash and highlight.
final
child Widget
The widget below this widget in the tree.
final
doubleClickTime Duration
The maximum duration between two taps for them to be considered a double-tap. Defaults to 300 milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
The highlight color of the CustomInkWell when it's pressed.
final
hoverColor Color?
The hover color of the CustomInkWell when it's hovered over.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDoubleTap VoidCallback?
Called when the user double-taps this CustomInkWell.
final
onSecondaryTapDown → void Function(TapDownDetails details, RenderBox renderBox)?
Called when the user performs a secondary tap down (e.g., right-click on desktop) on this CustomInkWell. Provides TapDownDetails and RenderBox for position calculations.
final
onTap VoidCallback?
Called when the user taps this CustomInkWell.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
The color of the ink splash when the CustomInkWell is tapped.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomInkWell>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited