TablePlusBodyTheme class

Theme configuration for the table body.

Constructors

TablePlusBodyTheme({double rowHeight = 48.0, Color backgroundColor = Colors.white, Color? alternateRowColor, Color? summaryRowBackgroundColor, TextStyle textStyle = const TextStyle(fontSize: 14, color: Color(0xFF212121)), Color selectedRowColor = const Color(0xFFE3F2FD), TextStyle? selectedRowTextStyle, Color? dimRowColor, TextStyle? dimRowTextStyle, Color? dimRowHoverColor, Color? dimRowSplashColor, Color? dimRowHighlightColor, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16.0), Color dividerColor = const Color(0xFFE0E0E0), double dividerThickness = 1.0, bool showVerticalDividers = true, bool showHorizontalDividers = true, LastRowBorderBehavior lastRowBorderBehavior = LastRowBorderBehavior.never, Color? hoverColor, Color? splashColor, Color? highlightColor, Color? selectedRowHoverColor, Color? selectedRowSplashColor, Color? selectedRowHighlightColor, Duration doubleClickTime = const Duration(milliseconds: 500)})
Creates a TablePlusBodyTheme with the specified styling properties.
const

Properties

alternateRowColor Color?
The alternate row color for striped tables. If null, all rows will use backgroundColor.
final
backgroundColor Color
The background color of rows.
final
dimRowColor Color?
The background color for dim rows. Dim rows are rows that meet a certain condition (determined by isDimRow callback). If null, dim rows will use normal row colors.
final
dimRowHighlightColor Color?
The highlight color for dim rows. If null, uses the default highlightColor.
final
dimRowHoverColor Color?
The hover color for dim rows. If null, uses the default hoverColor.
final
dimRowSplashColor Color?
The splash color for dim rows. If null, uses the default splashColor.
final
dimRowTextStyle TextStyle?
The text style for dim rows. If null, the default textStyle will be used.
final
dividerColor Color
The color of row dividers.
final
dividerThickness double
The thickness of row dividers.
final
doubleClickTime Duration
The maximum duration between two taps for them to be considered a double-tap. Defaults to 500 milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
The highlight color for unselected rows. If null, the default framework highlight effect is used. Use Colors.transparent to disable the highlight effect.
final
hoverColor Color?
The hover color for unselected rows. If null, the default framework hover effect is used. Use Colors.transparent to disable the hover effect.
final
lastRowBorderBehavior LastRowBorderBehavior
Controls when to show bottom border on the last row.
final
padding EdgeInsets
The padding inside body cells.
final
rowHeight double
The height of each data row.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedRowColor Color
The background color for selected rows.
final
selectedRowHighlightColor Color?
The highlight color for selected rows. If null, the default framework highlight effect is used. Use Colors.transparent to disable the highlight effect for selected rows.
final
selectedRowHoverColor Color?
The hover color for selected rows. If null, the default framework hover effect is used. Use Colors.transparent to disable the hover effect for selected rows.
final
selectedRowSplashColor Color?
The splash color for selected rows. If null, the default framework splash effect is used. Use Colors.transparent to disable the splash effect for selected rows.
final
selectedRowTextStyle TextStyle?
The text style for selected rows. If null, the default textStyle will be used.
final
showHorizontalDividers bool
Whether to show horizontal dividers between rows.
final
showVerticalDividers bool
Whether to show vertical dividers between columns.
final
splashColor Color?
The splash color for unselected rows. If null, the default framework splash effect is used. Use Colors.transparent to disable the splash effect.
final
summaryRowBackgroundColor Color?
The background color for summary rows in merged row groups. If null, will use backgroundColor with alpha 0.2.
final
textStyle TextStyle
The text style for body cells.
final
verticalDividerBorder Border?
A right-only Border for vertical column dividers, or null when disabled.
no setter
verticalDividerSide BorderSide
The right BorderSide for vertical column dividers between cells.
no setter

Methods

copyWith({double? rowHeight, Color? backgroundColor, Color? alternateRowColor, Color? summaryRowBackgroundColor, TextStyle? textStyle, Color? selectedRowColor, TextStyle? selectedRowTextStyle, Color? dimRowColor, TextStyle? dimRowTextStyle, Color? dimRowHoverColor, Color? dimRowSplashColor, Color? dimRowHighlightColor, EdgeInsets? padding, Color? dividerColor, double? dividerThickness, bool? showVerticalDividers, bool? showHorizontalDividers, LastRowBorderBehavior? lastRowBorderBehavior, Color? hoverColor, Color? splashColor, Color? highlightColor, Color? selectedRowHoverColor, Color? selectedRowSplashColor, Color? selectedRowHighlightColor, Duration? doubleClickTime}) TablePlusBodyTheme
Creates a copy of this theme with the given fields replaced with new values.
getEffectiveHighlightColor(bool isSelected, bool isDim) Color?
Gets the effective highlight color for rows based on selection and dim state. Priority: selected > dim > normal Returns null to use the default framework effect if no color is specified.
getEffectiveHoverColor(bool isSelected, bool isDim) Color?
Gets the effective hover color for rows based on selection and dim state. Priority: selected > dim > normal Returns null to use the default framework effect if no color is specified.
getEffectiveSplashColor(bool isSelected, bool isDim) Color?
Gets the effective splash color for rows based on selection and dim state. Priority: selected > dim > normal Returns null to use the default framework effect if no color is specified.
getEffectiveTextStyle(bool isSelected, bool isDim) TextStyle
Gets the effective text style for rows based on selection and dim state. Priority: selected > dim > normal Returns the appropriate text style based on row state.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldShowBottomBorder({required bool isLastRow, required bool needsVerticalScroll}) bool
Whether a bottom border should be shown for a row.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited