TablePlusTheme class

Theme configuration for the table components.

Constructors

TablePlusTheme({TablePlusHeaderTheme headerTheme = const TablePlusHeaderTheme(), TablePlusBodyTheme bodyTheme = const TablePlusBodyTheme(), TablePlusScrollbarTheme scrollbarTheme = const TablePlusScrollbarTheme(), TablePlusCheckboxTheme checkboxTheme = const TablePlusCheckboxTheme(), TablePlusEditableTheme editableTheme = const TablePlusEditableTheme(), TablePlusTooltipTheme tooltipTheme = const TablePlusTooltipTheme(), TablePlusHoverButtonTheme hoverButtonTheme = const TablePlusHoverButtonTheme()})
Creates a TablePlusTheme with the specified styling properties.
const

Properties

bodyTheme TablePlusBodyTheme
Theme configuration for the table body.
final
checkboxTheme TablePlusCheckboxTheme
Theme configuration for checkboxes.
final
editableTheme TablePlusEditableTheme
Theme configuration for cell editing.
final
hashCode int
The hash code for this object.
no setterinherited
headerTheme TablePlusHeaderTheme
Theme configuration for the table header.
final
hoverButtonTheme TablePlusHoverButtonTheme
Theme configuration for hover buttons.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarTheme TablePlusScrollbarTheme
Theme configuration for the scrollbars.
final
tooltipTheme TablePlusTooltipTheme
Theme configuration for cell tooltips.
final

Methods

copyWith({TablePlusHeaderTheme? headerTheme, TablePlusBodyTheme? bodyTheme, TablePlusScrollbarTheme? scrollbarTheme, TablePlusCheckboxTheme? checkboxTheme, TablePlusEditableTheme? editableTheme, TablePlusTooltipTheme? tooltipTheme, TablePlusHoverButtonTheme? hoverButtonTheme}) TablePlusTheme
Creates a copy of this theme with the given fields replaced with new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaledBy(double factor) TablePlusTheme
Returns a new TablePlusTheme with all dimensional values scaled by factor.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultTheme → const TablePlusTheme
Default table theme.