SortIcons class
Configuration for sort icons in table headers.
Constructors
Properties
- ascending → Widget
-
The icon to display when column is sorted in ascending order.
final
- descending → Widget
-
The icon to display when column is sorted in descending order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unsorted → Widget?
-
The icon to display when column is not sorted.
If null, no icon will be shown for unsorted columns.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultIcons → const SortIcons
- Default sort icons using Material Design icons.
- simple → const SortIcons
- Simple sort icons without unsorted state.