TablePlusHoverButtonTheme class
Theme configuration for hover buttons in table rows.
Constructors
- TablePlusHoverButtonTheme({double horizontalOffset = 8.0})
-
Creates a TablePlusHoverButtonTheme with the specified styling properties.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalOffset → double
-
The horizontal offset from the row edge for left/right positioned buttons.
This controls how far the buttons are positioned from the left or right edge of the row.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? horizontalOffset}) → TablePlusHoverButtonTheme - Creates a copy of this theme with the given fields replaced with new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scaledBy(
double factor) → TablePlusHoverButtonTheme -
Returns a new TablePlusHoverButtonTheme with dimensional values scaled by
factor. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultTheme → const TablePlusHoverButtonTheme
- Default hover button theme.